# dgtl-logging
NEN7513 compliant logging library according to the current scope of DGTL Health BV


## Updating
- update `setup.py` with new version number
- push or merge pull request to master branch and a github action will build and publish the package